import Cookie
import os

from common.appengine_utilities import sessions


class SessionMiddleware(object):
    TEST_COOKIE_NAME = 'testcookie'
    TEST_COOKIE_VALUE = 'worked'

    def process_request(self, request):
        """
        Check to see if a valid session token exists, if not,
        then use a cookie only session. It's up to the application
        to convert the session to a datastore session. Once this
        has been done, the session will continue to use the datastore
        unless the writer is set to "cookie".

        Setting the session to use the datastore is as easy as resetting
        request.session anywhere if your application.

        Example:
            from common.appengine_utilities import sessions
            request.session = sessions.Session()
        """
        self.request = request
        if sessions.Session.check_token():
            request.session = sessions.Session()
        else:
            request.session = sessions.Session(writer="cookie")
        request.session.set_test_cookie = self.set_test_cookie
        request.session.test_cookie_worked = self.test_cookie_worked
        request.session.delete_test_cookie = self.delete_test_cookie
        request.session.save = self.save
        return None

    def set_test_cookie(self):
        string_cookie = os.environ.get('HTTP_COOKIE', '')

        self.cookie = Cookie.SimpleCookie()
        self.cookie.load(string_cookie)
        self.cookie[self.TEST_COOKIE_NAME] = self.TEST_COOKIE_VALUE
        print self.cookie

    def test_cookie_worked(self):
        string_cookie = os.environ.get('HTTP_COOKIE', '')

        self.cookie = Cookie.SimpleCookie()
        self.cookie.load(string_cookie)

        return self.cookie.get(self.TEST_COOKIE_NAME)

    def delete_test_cookie(self):
        string_cookie = os.environ.get('HTTP_COOKIE', '')

        self.cookie = Cookie.SimpleCookie()
        self.cookie.load(string_cookie)
        self.cookie[self.TEST_COOKIE_NAME] = ''
        self.cookie[self.TEST_COOKIE_NAME]['path'] = '/'
        self.cookie[self.TEST_COOKIE_NAME]['expires'] = 0

    def save(self):
        self.request.session = sessions.Session()

    def process_response(self, request, response):
        if hasattr(request, "session"):
            response.cookies= request.session.output_cookie
        return response



#!/usr/bin/python
#
# Copyright (C) 2006 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


__author__ = 'api.jscudder@gmail.com (Jeff Scudder)'


import unittest

class ModuleTestRunner(object):

  def __init__(self, module_list=None, module_settings=None):
    """Constructor for a runner to run tests in the modules listed.

    Args:
      module_list: list (optional) The modules whose test cases will be run.
      module_settings: dict (optional) A dictionary of module level varables
          which should be set in the modules if they are present. An
          example is the username and password which is a module variable
          in most service_test modules.
    """
    self.modules = module_list or []
    self.settings = module_settings or {}

  def RunAllTests(self):
    """Executes all tests in this objects modules list.

    It also sets any module variables which match the settings keys to the
    corresponding values in the settings member.
    """
    runner = unittest.TextTestRunner()
    for module in self.modules:
      # Set any module variables according to the contents in the settings
      for setting, value in self.settings.iteritems():
        try:
          setattr(module, setting, value)
        except AttributeError:
          # This module did not have a variable for the current setting, so
          # we skip it and try the next setting.
          pass
      # We have set all of the applicable settings for the module, now
      # run the tests.
      print '\nRunning all tests in module', module.__name__
      runner.run(unittest.defaultTestLoader.loadTestsFromModule(module))    



#!/usr/bin/python
#
# Copyright (C) 2009 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Note:
# This sample demonstrates 2 Legged OAuth using v2 of the Google Data APIs.
# See 2_legged_oauth.py for an example of using 2LO with v1.0 of the APIs.

__author__ = 'e.bidelman (Eric Bidelman)'

import gdata.gauth
import gdata.contacts.client
import gdata.docs.client

SOURCE_APP_NAME = 'google-PyClient2LOSample-v2.0'

CONSUMER_KEY = 'yourdomain.com'
CONSUMER_SECRET = 'YOUR_CONSUMER_KEY'

def PrintContacts(client):
  print '\nListing contacts for %s...' % client.auth_token.requestor_id
  feed = client.GetContacts()
  for entry in feed.entry:
    print entry.title.text


# Contacts Data API Example ====================================================
requestor_id = 'any.user@' + CONSUMER_KEY
two_legged_oauth_token = gdata.gauth.TwoLeggedOAuthHmacToken(
    CONSUMER_KEY, CONSUMER_SECRET, requestor_id)

contacts_client = gdata.contacts.client.ContactsClient(source=SOURCE_APP_NAME)
contacts_client.auth_token = two_legged_oauth_token

# GET - fetch user's contact list
PrintContacts(contacts_client)

# GET - fetch another user's contact list
contacts_client.auth_token.requestor_id = 'different.user' + CONSUMER_KEY
PrintContacts(contacts_client)


# Documents List Data API Example ==============================================
docs_client = gdata.docs.client.DocsClient(source=SOURCE_APP_NAME)
docs_client.auth_token = two_legged_oauth_token
docs_client.ssl = True

# POST - upload a document
print "\nUploading doc to %s's account..." % docs_client.auth_token.requestor_id
entry = docs_client.Upload('test.txt', 'MyDocTitle', content_type='text/plain')
print 'Document now accessible online at:', entry.GetAlternateLink().href

# GET - fetch the user's document list
print '\nListing Google Docs for %s...' % docs_client.auth_token.requestor_id
feed = docs_client.GetDocList()
for entry in feed.entry:
  print entry.title.text



#!/usr/bin/python
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Sample for the User Provisioning API to demonstrate all methods.

Usage:
  $ python userprovisioning_quick_start_example.py

You can also specify the  user credentials from the command-line

  $ python userprovisioning_quick_start_example.py
    --client_id [client_id] --client_secret [client_scret] --domain [domain]

You can get help for command-line arguments as

  $ python userprovisioning_quick_start_example.py --help
"""

__author__ = 'Shraddha Gupta <shraddhag@google.com>'

import getopt
import getpass
import sys
import gdata.apps.client

SCOPE = 'https://apps-apis.google.com/a/feeds/user/'
USER_AGENT = 'UserProvisioningQuickStartExample'


class UserProvisioning(object):
  """Demonstrates all the functions of user provisioning."""

  def __init__(self, client_id, client_secret, domain):
    """
    Args:
      client_id: [string] The clientId of the developer.
      client_secret: [string] The clientSecret of the developer.
      domain: [string] The domain on which the functions are to be performed.
    """
    self.client_id = client_id
    self.client_secret = client_secret
    self.domain = domain

  def _AuthorizeClient(self):
    """Authorize the client for making API requests."""

    self.token = gdata.gauth.OAuth2Token(
        client_id=self.client_id, client_secret=self.client_secret,
        scope=SCOPE, user_agent=USER_AGENT)
    uri = self.token.generate_authorize_url()
    print 'Please visit this URL to authorize the application:'
    print uri
    # Get the verification code from the standard input.
    code = raw_input('What is the verification code? ').strip()
    self.token.get_access_token(code)
    self.client = gdata.apps.client.AppsClient(
        domain=self.domain, auth_token=self.token)

  def _PrintUserDetails(self, entry):
    """Prints the attributes for a user entry.

    Args:
      entry: [UserEntry] User entry corresponding to a user
    """
    print '\nGiven Name: %s' % (entry.name.given_name)
    print 'Family Name: %s' % (entry.name.family_name)
    print 'Username: %s' % (entry.login.user_name)
    print 'Is Admin: %s' % (entry.login.admin)
    print 'Is Suspended: %s' % (entry.login.suspended)
    print 'Change password at next login: %s\n' % (
        entry.login.change_password)

  def _PrintNicknameDetails(self, entry):
    """Prints the attributes for a user nickname entry.

    Args:
      entry: [NicknameEntry]
    """
    print 'Username: %s' % (entry.login.user_name)
    print 'Nickname: %s\n' % (entry.nickname.name)

  def _GetChoice(self, for_value):
    choice = raw_input(('(Optional) Enter a choice for %s\n'
                        '1-True 2-False ') % (for_value))
    if choice == '1':
      return True
    return False

  def _CreateUser(self):
    """Creates a new user account."""

    user_name = given_name = family_name = password = None
    confirm_password = ''
    while not user_name:
      user_name = raw_input('Enter a new username: ')
    while not given_name:
      given_name = raw_input('Enter given name for the user: ')
    while not family_name:
      family_name = raw_input('Enter family name for the user: ')
    while not password == confirm_password:
      password = ''
      while not password:
        sys.stdout.write('Enter password for the user: ')
        password = getpass.getpass()
        if password.__len__() == 0:
          break
        if password.__len__() < 8:
          print 'Password must be at least 8 characters long'
          password = ''
      sys.stdout.write('Confirm password: ')
      confirm_password = getpass.getpass()

    is_admin = self._GetChoice('is_admin ')
    hash_function = raw_input('(Optional) Enter a hash function ')
    suspended = self._GetChoice('suspended ')
    change_password = self._GetChoice('change_password ')
    quota = raw_input('(Optional) Enter a quota ')

    if quota == 'None' or not quota.isdigit():
      quota = None
    user_entry = self.client.CreateUser(
        user_name=user_name, given_name=given_name, family_name=family_name,
        password=password, admin=is_admin, suspended=suspended,
        password_hash_function=hash_function,
        change_password=change_password)
    self._PrintUserDetails(user_entry)
    print 'User Created'

  def _UpdateUser(self):
    """Updates a user."""

    user_name = raw_input('Enter the username ')
    if user_name is None:
      print 'Username missing\n'
      return
    user_entry = self.client.RetrieveUser(user_name=user_name)
    print self._PrintUserDetails(user_entry)

    attributes = {1: 'given_name', 2: 'family_name', 3: 'user_name',
                  4: 'suspended', 5: 'is_admin'}
    print attributes
    attr = int(raw_input('\nEnter number(1-5) of attribute to be updated '))

    updated_val = raw_input('Enter updated value ')
    if attr == 1:
      user_entry.name.given_name = updated_val
    if attr == 2:
      user_entry.name.family_name = updated_val
    if attr == 3:
      user_entry.login.user_name = updated_val
    if attr == 4:
      user_entry.login.suspended = updated_val
    if attr == 5:
      user_entry.login.admin = updated_val

    updated = self.client.UpdateUser(user_entry.login.user_name, user_entry)
    self._PrintUserDetails(updated)

  def _RetrieveSingleUser(self):
    """Retrieves a single user."""

    user_name = raw_input('Enter the username ')
    if user_name is None:
      print 'Username missing\n'
      return
    response = self.client.RetrieveUser(user_name=user_name)
    self._PrintUserDetails(response)

  def _RetrieveAllUsers(self):
    """Retrieves all users from all the domains."""

    response = self.client.RetrieveAllUsers()
    for entry in response.entry:
      self._PrintUserDetails(entry)

  def _DeleteUser(self):
    """Deletes a user."""

    user_name = raw_input('Enter the username ')
    if user_name is None:
      print 'Username missing\n'
      return

    self.client.DeleteUser(user_name=user_name)
    print 'User Deleted'

  def _CreateNickname(self):
    """Creates a user alias."""

    user_name = raw_input('Enter the username ')
    nickname = raw_input('Enter a nickname for user ')
    if None in (user_name, nickname):
      print 'Username/Nickname missing\n'
      return
    nickname = self.client.CreateNickname(
        user_name=user_name, nickname=nickname)
    print nickname
    print 'Nickname Created'

  def _RetrieveNickname(self):
    """Retrieves a nickname entry."""

    nickname = raw_input('Enter the username ')
    if nickname is None:
      print 'Nickname missing\n'
      return
    response = self.client.RetrieveNickname(nickname=nickname)
    self._PrintNicknameDetails(response)

  def _RetrieveUserNicknames(self):
    """Retrieves all nicknames of a user."""

    user_name = raw_input('Enter the username ')
    if user_name is None:
      print 'Username missing\n'
      return
    response = self.client.RetrieveNicknames(user_name=user_name)
    for entry in response.entry:
      self._PrintNicknameDetails(entry)

  def _DeleteNickname(self):
    """Deletes a nickname."""

    nickname = raw_input('Enter the username ')
    if nickname is None:
      print 'Nickname missing\n'
      return
    self.client.DeleteNickname(nickname=nickname)
    print 'Nickname deleted'

  def Run(self):
    """Runs the sample by getting user input and taking appropriate action."""

    # List of all the functions and their descriptions
    functions_list = [
        {'function': self._CreateUser,
         'description': 'Create a user'},
        {'function': self._UpdateUser,
         'description': 'Update a user'},
        {'function': self._RetrieveSingleUser,
         'description': 'Retrieve a single user'},
        {'function': self._RetrieveAllUsers,
         'description': 'Retrieve all users'},
        {'function': self._DeleteUser,
         'description': 'Delete a user'},
        {'function': self._CreateNickname,
         'description': 'Create a nickname'},
        {'function': self._RetrieveNickname,
         'description': 'Retrieve a nickname'},
        {'function': self._RetrieveUserNicknames,
         'description': 'Retrieve all nicknames for a user'},
        {'function': self._DeleteNickname,
         'description': 'Delete a nickname'}
    ]
    self._AuthorizeClient()
    while True:
      print '\nChoose an option:\n0 - to exit'
      for i in range (0, len(functions_list)):
        print '%d - %s' % ((i+1), functions_list[i]['description'])
      choice = int(raw_input())
      if choice == 0:
        break
      if choice < 0 or choice > 11:
        print 'Not a valid option!'
        continue
      functions_list[choice-1]['function']()


def main():
  """A menu driven application to demo all methods of user provisioning."""

  usage = ('python userprovisioning_quick_start_example.py '
           '--client_id [clientId] --client_secret [clientSecret] '
           '--domain [domain]')
  # Parse command line options
  try:
    opts, args = getopt.getopt(sys.argv[1:], '', ['client_id=',
                                                  'client_secret=',
                                                  'domain='])
  except getopt.error, msg:
    print 'Usage: %s' % usage
    return

  client_id = None
  client_secret = None
  domain = None
  # Parse options
  for option, arg in opts:
    if option == '--client_id':
      client_id = arg
    elif option == '--client_secret':
      client_secret = arg
    elif option == '--domain':
      domain = arg

  if None in (client_id, client_secret, domain):
    print 'Usage: %s' % usage
    return

  try:
    user_provisioning = UserProvisioning(client_id, client_secret, domain)
  except gdata.service.BadAuthentication:
    print 'Invalid user credentials given.'
    return

  user_provisioning.Run()


if __name__ == '__main__':
  main()



#!/usr/bin/python
#
# Copyright (C) 2007 Google Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


__author__ = 'api.laurabeth@gmail.com (Laura Beth Lincoln)'


try:
  from xml.etree import ElementTree
except ImportError:
  from elementtree import ElementTree
import gdata.spreadsheet.service
import gdata.service
import atom.service
import gdata.spreadsheet
import atom
import getopt
import sys
import string


class SimpleCRUD:

  def __init__(self, email, password):
    self.gd_client = gdata.spreadsheet.service.SpreadsheetsService()
    self.gd_client.email = email
    self.gd_client.password = password
    self.gd_client.source = 'Spreadsheets GData Sample'
    self.gd_client.ProgrammaticLogin()
    self.curr_key = ''
    self.curr_wksht_id = ''
    self.list_feed = None
    
  def _PromptForSpreadsheet(self):
    # Get the list of spreadsheets
    feed = self.gd_client.GetSpreadsheetsFeed()
    self._PrintFeed(feed)
    input = raw_input('\nSelection: ')
    id_parts = feed.entry[string.atoi(input)].id.text.split('/')
    self.curr_key = id_parts[len(id_parts) - 1]
  
  def _PromptForWorksheet(self):
    # Get the list of worksheets
    feed = self.gd_client.GetWorksheetsFeed(self.curr_key)
    self._PrintFeed(feed)
    input = raw_input('\nSelection: ')
    id_parts = feed.entry[string.atoi(input)].id.text.split('/')
    self.curr_wksht_id = id_parts[len(id_parts) - 1]
  
  def _PromptForCellsAction(self):
    print ('dump\n'
           'update {row} {col} {input_value}\n'
           '\n')
    input = raw_input('Command: ')
    command = input.split(' ', 1)
    if command[0] == 'dump':
      self._CellsGetAction()
    elif command[0] == 'update':
      parsed = command[1].split(' ', 2)
      if len(parsed) == 3:
        self._CellsUpdateAction(parsed[0], parsed[1], parsed[2])
      else:
        self._CellsUpdateAction(parsed[0], parsed[1], '')
    else:
      self._InvalidCommandError(input)
  
  def _PromptForListAction(self):
    print ('dump\n'
           'insert {row_data} (example: insert label=content)\n'
           'update {row_index} {row_data}\n'
           'delete {row_index}\n'
           'Note: No uppercase letters in column names!\n'
           '\n')
    input = raw_input('Command: ')
    command = input.split(' ' , 1)
    if command[0] == 'dump':
      self._ListGetAction()
    elif command[0] == 'insert':
      self._ListInsertAction(command[1])
    elif command[0] == 'update':
      parsed = command[1].split(' ', 1)
      self._ListUpdateAction(parsed[0], parsed[1])
    elif command[0] == 'delete':
      self._ListDeleteAction(command[1])
    else:
      self._InvalidCommandError(input)
  
  def _CellsGetAction(self):
    # Get the feed of cells
    feed = self.gd_client.GetCellsFeed(self.curr_key, self.curr_wksht_id)
    self._PrintFeed(feed)
    
  def _CellsUpdateAction(self, row, col, inputValue):
    entry = self.gd_client.UpdateCell(row=row, col=col, inputValue=inputValue, 
        key=self.curr_key, wksht_id=self.curr_wksht_id)
    if isinstance(entry, gdata.spreadsheet.SpreadsheetsCell):
      print 'Updated!'
        
  def _ListGetAction(self):
    # Get the list feed
    self.list_feed = self.gd_client.GetListFeed(self.curr_key, self.curr_wksht_id)
    self._PrintFeed(self.list_feed)
    
  def _ListInsertAction(self, row_data):
    entry = self.gd_client.InsertRow(self._StringToDictionary(row_data), 
        self.curr_key, self.curr_wksht_id)
    if isinstance(entry, gdata.spreadsheet.SpreadsheetsList):
      print 'Inserted!'
        
  def _ListUpdateAction(self, index, row_data):
    self.list_feed = self.gd_client.GetListFeed(self.curr_key, self.curr_wksht_id)
    entry = self.gd_client.UpdateRow(
        self.list_feed.entry[string.atoi(index)], 
        self._StringToDictionary(row_data))
    if isinstance(entry, gdata.spreadsheet.SpreadsheetsList):
      print 'Updated!'
  
  def _ListDeleteAction(self, index):
    self.list_feed = self.gd_client.GetListFeed(self.curr_key, self.curr_wksht_id)
    self.gd_client.DeleteRow(self.list_feed.entry[string.atoi(index)])
    print 'Deleted!'
    
  def _StringToDictionary(self, row_data):
    dict = {}
    for param in row_data.split():
      temp = param.split('=')
      dict[temp[0]] = temp[1]
    return dict
  
  def _PrintFeed(self, feed):
    for i, entry in enumerate(feed.entry):
      if isinstance(feed, gdata.spreadsheet.SpreadsheetsCellsFeed):
        print '%s %s\n' % (entry.title.text, entry.content.text)
      elif isinstance(feed, gdata.spreadsheet.SpreadsheetsListFeed):
        print '%s %s %s' % (i, entry.title.text, entry.content.text)
        # Print this row's value for each column (the custom dictionary is
        # built using the gsx: elements in the entry.)
        print 'Contents:'
        for key in entry.custom:  
          print '  %s: %s' % (key, entry.custom[key].text) 
        print '\n',
      else:
        print '%s %s\n' % (i, entry.title.text)
        
  def _InvalidCommandError(self, input):
    print 'Invalid input: %s\n' % (input)
    
  def Run(self):
    self._PromptForSpreadsheet()
    self._PromptForWorksheet()
    input = raw_input('cells or list? ')
    if input == 'cells':
      while True:
        self._PromptForCellsAction()
    elif input == 'list':
      while True:
        self._PromptForListAction()


def main():
  # parse command line options
  try:
    opts, args = getopt.getopt(sys.argv[1:], "", ["user=", "pw="])
  except getopt.error, msg:
    print 'python spreadsheetExample.py --user [username] --pw [password] '
    sys.exit(2)
  
  user = ''
  pw = ''
  key = ''
  # Process options
  for o, a in opts:
    if o == "--user":
      user = a
    elif o == "--pw":
      pw = a

  if user == '' or pw == '':
    print 'python spreadsheetExample.py --user [username] --pw [password] '
    sys.exit(2)
        
  sample = SimpleCRUD(user, pw)
  sample.Run()


if __name__ == '__main__':
  main()



#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Live client tests for the Multidomain Provisioning API."""

# This module is used for version 2 of the Google Data APIs.
# These tests attempt to connect to Google servers.


__author__ = 'Claudio Cherubino <ccherubino@google.com>'


import random
import unittest
import gdata.apps.multidomain.client
import gdata.apps.multidomain.data
import gdata.client
import gdata.data
import gdata.gauth
import gdata.test_config as conf

conf.options.register_option(conf.APPS_DOMAIN_OPTION)


class MultidomainProvisioningClientTest(unittest.TestCase):

  def setUp(self):
    self.client = gdata.apps.multidomain.client.MultiDomainProvisioningClient(
        domain='example.com')
    if conf.options.get_value('runlive') == 'true':
      self.client = gdata.apps.multidomain.client.MultiDomainProvisioningClient(
          domain=conf.options.get_value('appsdomain'))
      if conf.options.get_value('ssl') == 'true':
        self.client.ssl = True
      conf.configure_client(self.client, 'MultidomainProvisioningClientTest',
          self.client.auth_service, True)

  def tearDown(self):
    conf.close_client(self.client)

  def testClientConfiguration(self):
    self.assertEqual('apps-apis.google.com', self.client.host)
    self.assertEqual('2.0', self.client.api_version)
    self.assertEqual('apps', self.client.auth_service)
    self.assertEqual(gdata.gauth.AUTH_SCOPES['apps'], self.client.auth_scopes)
    if conf.options.get_value('runlive') == 'true':
      self.assertEqual(self.client.domain, conf.options.get_value('appsdomain'))
    else:
      self.assertEqual(self.client.domain, 'example.com')

  def testMakeMultidomainUserProvisioningUri(self):
    self.assertEqual('/a/feeds/user/2.0/%s' % self.client.domain,
        self.client.MakeMultidomainUserProvisioningUri())
    self.assertEqual('/a/feeds/user/2.0/%s/liz@example.com'
        % self.client.domain,
        self.client.MakeMultidomainUserProvisioningUri(
            email='liz@example.com'))
    self.assertEqual('/a/feeds/user/2.0/%s?start=%s'
        % (self.client.domain, 'liz%40example.com'),
        self.client.MakeMultidomainUserProvisioningUri(
            params={'start': 'liz@example.com'}))

  def testMakeMultidomainAliasProvisioningUri(self):
    self.assertEqual('/a/feeds/alias/2.0/%s' % self.client.domain,
        self.client.MakeMultidomainAliasProvisioningUri())
    self.assertEqual('/a/feeds/alias/2.0/%s/liz@example.com'
        % self.client.domain,
        self.client.MakeMultidomainAliasProvisioningUri(
            email='liz@example.com'))
    self.assertEqual('/a/feeds/alias/2.0/%s?start=%s'
        % (self.client.domain, 'liz%40example.com'),
        self.client.MakeMultidomainAliasProvisioningUri(
            params={'start': 'liz@example.com'}))

  def testCreateRetrieveUpdateDelete(self):
    if not conf.options.get_value('runlive') == 'true':
      return

    # Either load the recording or prepare to make a live request.
    conf.configure_cache(self.client, 'testCreateUpdateDelete')

    rnd_number = random.randrange(0, 100001)
    email = 'test_user%s@%s' % (rnd_number, self.client.domain)
    alias = 'test_alias%s@%s' % (rnd_number, self.client.domain)

    new_entry = self.client.CreateUser(
        email, 'Elizabeth', 'Smith',
        '51eea05d46317fadd5cad6787a8f562be90b4446', 'true',
        hash_function='SHA-1')

    self.assert_(isinstance(new_entry,
        gdata.apps.multidomain.data.UserEntry))
    self.assertEquals(new_entry.first_name, 'Elizabeth')
    self.assertEquals(new_entry.last_name, 'Smith')
    self.assertEquals(new_entry.email, email)
    self.assertEquals(new_entry.password,
        '51eea05d46317fadd5cad6787a8f562be90b4446')
    self.assertEquals(new_entry.is_admin, 'true')

    fetched_entry = self.client.RetrieveUser(email=email)
    self.assertEquals(fetched_entry.first_name, 'Elizabeth')
    self.assertEquals(fetched_entry.last_name, 'Smith')
    self.assertEquals(fetched_entry.email, email)
    self.assertEquals(fetched_entry.is_admin, 'true')

    new_entry.first_name = 'Joe'
    new_entry.last_name = 'Brown'
    updated_entry = self.client.UpdateUser(
        email=email, user_entry=new_entry)
    self.assert_(isinstance(updated_entry,
        gdata.apps.multidomain.data.UserEntry))
    self.assertEqual(updated_entry.first_name, 'Joe')
    self.assertEqual(updated_entry.last_name, 'Brown')

    new_email = 'renamed_user%s@%s' % (rnd_number, self.client.domain)
    renamed_entry = self.client.RenameUser(
        old_email=email, new_email=new_email)
    self.assert_(isinstance(renamed_entry,
        gdata.apps.multidomain.data.UserRenameRequest))
    self.assertEqual(renamed_entry.new_email, new_email)

    new_alias = self.client.CreateAlias(new_email, alias)
    self.assert_(isinstance(new_alias,
        gdata.apps.multidomain.data.AliasEntry))
    self.assertEquals(new_alias.user_email, new_email)
    self.assertEquals(new_alias.alias_email, alias)

    fetched_alias = self.client.RetrieveAlias(alias)
    self.assertEquals(fetched_alias.user_email, new_email)
    self.assertEquals(fetched_alias.alias_email, alias)

    fetched_aliases = self.client.RetrieveAllUserAliases(new_email)
    self.assertEquals(fetched_aliases.entry[0].user_email, new_email)
    self.assertEquals(fetched_aliases.entry[0].alias_email, email)
    self.assertEquals(fetched_aliases.entry[1].user_email, new_email)
    self.assertEquals(fetched_aliases.entry[1].alias_email, alias)

    self.client.DeleteAlias(alias)
    self.client.DeleteUser(new_email)


def suite():
  return conf.build_suite([MultidomainProvisioningClientTest])


if __name__ == '__main__':
  unittest.TextTestRunner().run(suite())



#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Live client tests for the Groups Provisioning API."""

# This module is used for version 2 of the Google Data APIs.
# These tests attempt to connect to Google servers.


__author__ = 'Shraddha gupta <shraddhag@google.com>'


import random
import unittest
import gdata.apps.groups.client
import gdata.apps.groups.data
import gdata.client
import gdata.data
import gdata.gauth
import gdata.test_config as conf

conf.options.register_option(conf.APPS_DOMAIN_OPTION)


class GroupsProvisioningClientTest(unittest.TestCase):

  def setUp(self):
    self.client = gdata.apps.groups.client.GroupsProvisioningClient(
        domain='example.com')
    if conf.options.get_value('runlive') == 'true':
      self.client = gdata.apps.groups.client.GroupsProvisioningClient(
          domain=conf.options.get_value('appsdomain'))
      if conf.options.get_value('ssl') == 'true':
        self.client.ssl = True
      conf.configure_client(self.client, 'GroupsProvisioningClientTest',
          self.client.auth_service, True)

  def tearDown(self):
    conf.close_client(self.client)

  def testClientConfiguration(self):
    self.assertEqual('apps-apis.google.com', self.client.host)
    self.assertEqual('2.0', self.client.api_version)
    self.assertEqual('apps', self.client.auth_service)
    self.assertEqual(
        ('https://apps-apis.google.com/a/feeds/user/',
         'https://apps-apis.google.com/a/feeds/policies/',
         'https://apps-apis.google.com/a/feeds/alias/',
         'https://apps-apis.google.com/a/feeds/groups/'),
         self.client.auth_scopes)
    if conf.options.get_value('runlive') == 'true':
      self.assertEqual(self.client.domain, conf.options.get_value('appsdomain'))
    else:
      self.assertEqual(self.client.domain, 'example.com')

  def testMakeGroupProvisioningUri(self):
    self.assertEqual('/a/feeds/group/2.0/%s' % self.client.domain,
        self.client.MakeGroupProvisioningUri())
    self.assertEqual('/a/feeds/group/2.0/%s/firstgroup@example.com'
        % self.client.domain,
        self.client.MakeGroupProvisioningUri(group_id='firstgroup@example.com'))
    self.assertEqual(
        '/a/feeds/group/2.0/%s?member=member1' % self.client.domain,
        self.client.MakeGroupProvisioningUri(params={'member':'member1'}))

  def testMakeGroupMembersUri(self):
    self.assertEqual('/a/feeds/group/2.0/%s/firstgroup@example.com/member'
        % self.client.domain,
        self.client.MakeGroupMembersUri(group_id='firstgroup@example.com'))
    self.assertEqual(
        '/a/feeds/group/2.0/%s/firstgroup@example.com/member/liz@example.com'
        % self.client.domain,
        self.client.MakeGroupMembersUri(
            group_id='firstgroup@example.com', member_id='liz@example.com'))

  def testCreateRetrieveUpdateDelete(self):
    if not conf.options.get_value('runlive') == 'true':
      return

    # Either load the recording or prepare to make a live request.
    conf.configure_cache(self.client, 'testCreateUpdateDelete')

    rnd_number = random.randrange(0, 100)
    group_id = 'test_groupid%s@%s' % (rnd_number, self.client.domain)
    group_name = 'test_groupname%s' % (rnd_number)
    member_id = 'test_member%s@%s' % (rnd_number, self.client.domain)

    new_group = self.client.CreateGroup(
        group_id=group_id, group_name=group_name, description='Test Group',
        email_permission='Domain')

    self.assert_(isinstance(new_group,
        gdata.apps.groups.data.GroupEntry))
    self.assertEquals(new_group.group_id, group_id)
    self.assertEquals(new_group.group_name, group_name)
    self.assertEquals(new_group.description, 'Test Group')
    self.assertEquals(new_group.email_permission, 'Domain')

    fetched_entry = self.client.RetrieveGroup(group_id=group_id)
    self.assert_(isinstance(fetched_entry,
        gdata.apps.groups.data.GroupEntry))
    self.assertEquals(new_group.group_id, group_id)
    self.assertEquals(new_group.group_name, group_name)
    self.assertEquals(new_group.description, 'Test Group')
    self.assertEquals(new_group.email_permission, 'Domain')

    new_group.group_name = 'updated name'
    updated_group = self.client.UpdateGroup(
        group_id=group_id, group_entry=new_group)
    self.assert_(isinstance(updated_group,
        gdata.apps.groups.data.GroupEntry))
    self.assertEqual(updated_group.group_name, 'updated name')

    new_member = self.client.AddMemberToGroup(group_id=group_id,
        member_id=member_id)
    self.assert_(isinstance(new_member,
        gdata.apps.groups.data.GroupMemberEntry))
    self.assertEquals(new_member.member_id, member_id)

    fetched_member = self.client.RetrieveGroupMember(group_id=group_id,
        member_id=member_id)
    self.assertEquals(fetched_member.member_id, member_id)

    self.client.RemoveMemberFromGroup(group_id=group_id,
        member_id=member_id)
    self.client.DeleteGroup(group_id=group_id)


def suite():
  return conf.build_suite([GroupsProvisioningClientTest])


if __name__ == '__main__':
  unittest.TextTestRunner().run(suite())



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import getpass

from gdata.contentforshopping.data import build_entry
from gdata.contentforshopping.client import ContentForShoppingClient

# Gather merchant information
account_id = raw_input('Merchant Account ID? ').strip()
email = raw_input('Google Email Address? ').strip()

# Create a client
client = ContentForShoppingClient(account_id)

# Perform programmatic login
client.client_login(email, getpass.getpass('Google Password? '),
    'Shopping API for Content sample', 'structuredcontent')

products = []

for color in ['red', 'green', 'white', 'black', 'purple', 'brown', 'yellow',
              'orange', 'magenta']:
  # Generate a product entry
  product_entry = build_entry(
    product_id='ipod%s' % color,
    target_country = 'US',
    content_language = 'EN',
    title='iPod Nano 8GB, %s' % color,
    content='A nice small mp3 player, in %s' % color,
    price='149',
    price_unit='USD',
    shipping_price = '5',
    shipping_price_unit = 'USD',
    tax_rate='17.5',
    condition = 'new',
    link = 'http://pseudoscience.co.uk/google4e823e35f032f011.html',
    color = color,
  )
  products.append(product_entry)

# Post it to the service
client.insert_products(products)



#!/usr/bin/python
#
# Copyright 2009 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


__author__ = 'e.bidelman (Eric Bidelman)'

import unittest
import atom
from gdata import test_data
import gdata.acl.data
import gdata.data
import gdata.docs.data
import gdata.test_config as conf


class DocsEntryTest(unittest.TestCase):

  def setUp(self):
    self.entry = atom.core.parse(test_data.DOCUMENT_LIST_ENTRY_V3,
                                 gdata.docs.data.Resource)

  def testToAndFromStringDocsEntry(self):
    self.assert_(isinstance(self.entry, gdata.docs.data.Resource))
    self.assertEqual(self.entry.GetResourceType(), 'spreadsheet')
    self.assert_(isinstance(self.entry.last_viewed, gdata.docs.data.LastViewed))
    self.assertEqual(self.entry.last_viewed.text, '2009-03-05T07:48:21.493Z')
    self.assert_(
        isinstance(self.entry.last_modified_by, gdata.docs.data.LastModifiedBy))
    self.assertEqual(
        self.entry.last_modified_by.email.text, 'test.user@gmail.com')
    self.assertEqual(self.entry.last_modified_by.name.text, 'test.user')
    self.assert_(isinstance(self.entry.resource_id, gdata.docs.data.ResourceId))
    self.assertEqual(self.entry.resource_id.text,
                     'spreadsheet:supercalifragilisticexpealidocious')
    self.assert_(isinstance(self.entry.writers_can_invite,
                            gdata.docs.data.WritersCanInvite))
    self.assertEqual(self.entry.writers_can_invite.value, 'true')
    self.assert_(isinstance(self.entry.quota_bytes_used,
                            gdata.docs.data.QuotaBytesUsed))
    self.assertEqual(self.entry.quota_bytes_used.text, '1000')
    self.assertEqual(len(self.entry.feed_link), 2)
    self.assert_(isinstance(self.entry.feed_link[0], gdata.data.FeedLink))

    self.assertEqual(
        self.entry.GetAclFeedLink().href,
        ('https://docs.google.com/feeds/default/private/full/'
         'spreadsheet%3Asupercalifragilisticexpealidocious/acl'))
    self.assertEqual(
        self.entry.GetRevisionsFeedLink().href,
        ('https://docs.google.com/feeds/default/private/full/'
         'spreadsheet%3Asupercalifragilisticexpealidocious/revisions'))

    self.assertEqual(len(self.entry.InCollections()), 1)
    self.assertEqual(self.entry.InCollections()[0].title, 'AFolderName')


class AclTest(unittest.TestCase):

  def setUp(self):
    self.acl_entry = atom.core.parse(test_data.DOCUMENT_LIST_ACL_ENTRY,
                                     gdata.docs.data.AclEntry)
    self.acl_entry_withkey = atom.core.parse(
      test_data.DOCUMENT_LIST_ACL_WITHKEY_ENTRY, gdata.docs.data.AclEntry)
    self.acl_entry_additional_role = atom.core.parse(
      test_data.DOCUMENT_LIST_ACL_ADDITIONAL_ROLE_ENTRY,
      gdata.docs.data.AclEntry)

  def testToAndFromString(self):
    self.assert_(isinstance(self.acl_entry, gdata.docs.data.AclEntry))
    self.assert_(isinstance(self.acl_entry.role, gdata.acl.data.AclRole))
    self.assert_(isinstance(self.acl_entry.scope, gdata.acl.data.AclScope))
    self.assertEqual(self.acl_entry.scope.value, 'user@gmail.com')
    self.assertEqual(self.acl_entry.scope.type, 'user')
    self.assertEqual(self.acl_entry.role.value, 'writer')

    acl_entry_str = str(self.acl_entry)
    new_acl_entry = atom.core.parse(acl_entry_str, gdata.docs.data.AclEntry)
    self.assert_(isinstance(new_acl_entry, gdata.docs.data.AclEntry))
    self.assert_(isinstance(new_acl_entry.role, gdata.acl.data.AclRole))
    self.assert_(isinstance(new_acl_entry.scope, gdata.acl.data.AclScope))
    self.assertEqual(new_acl_entry.scope.value, self.acl_entry.scope.value)
    self.assertEqual(new_acl_entry.scope.type, self.acl_entry.scope.type)
    self.assertEqual(new_acl_entry.role.value, self.acl_entry.role.value)

  def testToAndFromStringWithKey(self):
    self.assert_(isinstance(self.acl_entry_withkey, gdata.docs.data.AclEntry))
    self.assert_(self.acl_entry_withkey.role is None)
    self.assert_(isinstance(self.acl_entry_withkey.with_key,
                            gdata.acl.data.AclWithKey))
    self.assert_(isinstance(self.acl_entry_withkey.with_key.role,
                            gdata.acl.data.AclRole))
    self.assert_(isinstance(self.acl_entry_withkey.scope,
                            gdata.acl.data.AclScope))
    self.assertEqual(self.acl_entry_withkey.with_key.key, 'somekey')
    self.assertEqual(self.acl_entry_withkey.with_key.role.value, 'writer')
    self.assertEqual(self.acl_entry_withkey.scope.value, 'example.com')
    self.assertEqual(self.acl_entry_withkey.scope.type, 'domain')

    acl_entry_withkey_str = str(self.acl_entry_withkey)
    new_acl_entry_withkey = atom.core.parse(acl_entry_withkey_str,
                                            gdata.docs.data.AclEntry)
    self.assert_(isinstance(new_acl_entry_withkey, gdata.docs.data.AclEntry))
    self.assert_(new_acl_entry_withkey.role is None)
    self.assert_(isinstance(new_acl_entry_withkey.with_key,
                            gdata.acl.data.AclWithKey))
    self.assert_(isinstance(new_acl_entry_withkey.with_key.role,
                            gdata.acl.data.AclRole))
    self.assert_(isinstance(new_acl_entry_withkey.scope,
                            gdata.acl.data.AclScope))
    self.assertEqual(new_acl_entry_withkey.with_key.key,
                     self.acl_entry_withkey.with_key.key)
    self.assertEqual(new_acl_entry_withkey.with_key.role.value,
                     self.acl_entry_withkey.with_key.role.value)
    self.assertEqual(new_acl_entry_withkey.scope.value,
                     self.acl_entry_withkey.scope.value)
    self.assertEqual(new_acl_entry_withkey.scope.type,
                     self.acl_entry_withkey.scope.type)

  def testCreateNewAclEntry(self):
    cat = gdata.atom.Category(
        term='http://schemas.google.com/acl/2007#accessRule',
        scheme='http://schemas.google.com/g/2005#kind')
    acl_entry = gdata.docs.DocumentListAclEntry(category=[cat])
    acl_entry.scope = gdata.docs.Scope(value='user@gmail.com', type='user')
    acl_entry.role = gdata.docs.Role(value='writer')
    self.assert_(isinstance(acl_entry, gdata.docs.DocumentListAclEntry))
    self.assert_(isinstance(acl_entry.role, gdata.docs.Role))
    self.assert_(isinstance(acl_entry.scope, gdata.docs.Scope))
    self.assertEqual(acl_entry.scope.value, 'user@gmail.com')
    self.assertEqual(acl_entry.scope.type, 'user')
    self.assertEqual(acl_entry.role.value, 'writer')

  def testAdditionalRole(self):
    self.assertEqual(
        self.acl_entry_additional_role.additional_role.value,
        'commenter')
    self.assertEqual(
        self.acl_entry_additional_role.with_key.additional_role.value,
        'commenter')


class AclFeedTest(unittest.TestCase):

  def setUp(self):
    self.feed = atom.core.parse(test_data.DOCUMENT_LIST_ACL_FEED,
                                gdata.docs.data.AclFeed)

  def testToAndFromString(self):
    for entry in self.feed.entry:
      self.assert_(isinstance(entry, gdata.docs.data.AclEntry))

    feed = atom.core.parse(str(self.feed), gdata.docs.data.AclFeed)
    for entry in feed.entry:
      self.assert_(isinstance(entry, gdata.docs.data.AclEntry))

  def testConvertActualData(self):
    entries = self.feed.entry
    self.assert_(len(entries) == 2)
    self.assertEqual(entries[0].title.text,
                     'Document Permission - user@gmail.com')
    self.assertEqual(entries[0].role.value, 'owner')
    self.assertEqual(entries[0].scope.type, 'user')
    self.assertEqual(entries[0].scope.value, 'user@gmail.com')
    self.assert_(entries[0].GetSelfLink() is not None)
    self.assert_(entries[0].GetEditLink() is not None)
    self.assertEqual(entries[1].title.text,
                     'Document Permission - user2@google.com')
    self.assertEqual(entries[1].role.value, 'writer')
    self.assertEqual(entries[1].scope.type, 'domain')
    self.assertEqual(entries[1].scope.value, 'google.com')
    self.assert_(entries[1].GetSelfLink() is not None)
    self.assert_(entries[1].GetEditLink() is not None)


class RevisionFeedTest(unittest.TestCase):

  def setUp(self):
    self.feed = atom.core.parse(test_data.DOCUMENT_LIST_REVISION_FEED,
                                gdata.docs.data.RevisionFeed)

  def testToAndFromString(self):
    for entry in self.feed.entry:
      self.assert_(isinstance(entry, gdata.docs.data.Revision))

    feed = atom.core.parse(str(self.feed), gdata.docs.data.RevisionFeed)
    for entry in feed.entry:
      self.assert_(isinstance(entry, gdata.docs.data.Revision))

  def testConvertActualData(self):
    entries = self.feed.entry
    self.assert_(len(entries) == 1)
    self.assertEqual(entries[0].title.text, 'Revision 2')
    self.assertEqual(entries[0].publish.value, 'true')
    self.assertEqual(entries[0].publish_auto.value, 'true')
    self.assertEqual(entries[0].publish_outside_domain.value, 'false')
    self.assertEqual(
         entries[0].GetPublishLink().href,
         'https://docs.google.com/View?docid=dfr4&pageview=1&hgd=1')
    self.assertEqual(
         entries[0].FindPublishLink(),
         'https://docs.google.com/View?docid=dfr4&pageview=1&hgd=1')


class DataClassSanityTest(unittest.TestCase):

  def test_basic_element_structure(self):
    conf.check_data_classes(self, [
        gdata.docs.data.ResourceId, gdata.docs.data.LastModifiedBy,
        gdata.docs.data.LastViewed, gdata.docs.data.WritersCanInvite,
        gdata.docs.data.QuotaBytesUsed, gdata.docs.data.Publish,
        gdata.docs.data.PublishAuto, gdata.docs.data.PublishOutsideDomain,
        gdata.docs.data.Resource, gdata.docs.data.AclEntry, gdata.docs.data.AclFeed,
        gdata.docs.data.ResourceFeed, gdata.docs.data.Revision,
        gdata.docs.data.RevisionFeed])


class CategoryTest(unittest.TestCase):

  def setUp(self):
    self.entry = atom.core.parse(test_data.DOCUMENT_LIST_ENTRY_V3,
                                 gdata.docs.data.Resource)

  def testAddCategory(self):
    entry = gdata.docs.data.Resource()
    entry.AddCategory('test_scheme', 'test_term', 'test_label')
    self.assertEqual(entry.GetFirstCategory('test_scheme').scheme,
                     'test_scheme')
    self.assertEqual(entry.GetFirstCategory('test_scheme').term, 'test_term')
    self.assertEqual(entry.GetFirstCategory('test_scheme').label, 'test_label')

  def testGetFirstCategory(self):
    entry = gdata.docs.data.Resource()
    cat1 = entry.AddCategory('test_scheme', 'test_term1', 'test_label1')
    cat2 = entry.AddCategory('test_scheme', 'test_term2', 'test_label2')
    self.assertEqual(entry.GetFirstCategory('test_scheme'), cat1)

  def testGetCategories(self):
    cat1 = self.entry.AddCategory('test_scheme', 'test_term1', 'test_label1')
    cat2 = self.entry.AddCategory('test_scheme', 'test_term2', 'test_label2')
    cats = list(self.entry.GetCategories('test_scheme'))
    self.assertTrue(cat1 in cats)
    self.assertTrue(cat2 in cats)

  def testRemoveCategories(self):
    self.entry.RemoveCategories(gdata.docs.data.LABELS_SCHEME)
    self.assertEqual(self.entry.GetLabels(), set())

  def testResourceType(self):
    entry = gdata.docs.data.Resource('spreadsheet')
    self.assertEqual(self.entry.GetResourceType(), 'spreadsheet')

  def testGetResourceType(self):
    self.assertEqual(self.entry.GetResourceType(), 'spreadsheet')

  def testSetResourceType(self):
    self.assertEqual(self.entry.GetResourceType(), 'spreadsheet')
    self.entry.SetResourceType('drawing')
    self.assertEqual(self.entry.GetResourceType(), 'drawing')

  def testGetLabels(self):
    self.assertEqual(self.entry.GetLabels(),
                     set(['mine', 'private', 'restricted-download',
                          'shared-with-domain', 'viewed', 'starred', 'hidden',
                          'trashed']))

  def testAddLabel(self):
    entry = gdata.docs.data.Resource()
    entry.AddLabel('banana')
    self.assertTrue('banana' in entry.GetLabels())

  def testRemoveLabel(self):
    entry = gdata.docs.data.Resource()
    entry.AddLabel('banana')
    entry.AddLabel('orange')
    self.assertTrue('banana' in entry.GetLabels())
    self.assertTrue('orange' in entry.GetLabels())
    entry.RemoveLabel('orange')
    self.assertFalse('orange' in entry.GetLabels())

  def testIsHidden(self):
    self.assertTrue(self.entry.IsHidden())

  def testIsNotHidden(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsHidden())

  def testIsViewed(self):
    self.assertTrue(self.entry.IsViewed())

  def testIsNotViewed(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsViewed())

  def testIsStarred(self):
    self.assertTrue(self.entry.IsStarred())

  def testIsNotStarred(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsStarred())

  def testIsTrashed(self):
    self.assertTrue(self.entry.IsTrashed())

  def testIsNotTrashed(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsTrashed())

  def testIsPrivate(self):
    self.assertTrue(self.entry.IsPrivate())

  def testIsNotPrivate(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsPrivate())

  def testIsMine(self):
    self.assertTrue(self.entry.IsMine())

  def testIsNotMine(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsMine())

  def testIsSharedWithDomain(self):
    self.assertTrue(self.entry.IsSharedWithDomain())

  def testIsNotSharedWithDomain(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsSharedWithDomain())

  def testIsRestrictedDownload(self):
    self.assertTrue(self.entry.IsRestrictedDownload())

  def testIsNotRestrictedDownload(self):
    self.entry.remove_categories(gdata.docs.data.LABELS_SCHEME)
    self.assertFalse(self.entry.IsRestrictedDownload())


class MetadataTest(unittest.TestCase):

  def setUp(self):
    self.entry = atom.core.parse(test_data.DOCUMENT_LIST_METADATA,
                                 gdata.docs.data.Metadata)

  def testAdditionalRoleInfo(self):
    self.assertEqual(self.entry.additional_role_info[0].kind, 'document')

  def testAdditionalRoleSet(self):
    self.assertEqual(
        self.entry.additional_role_info[0].additional_role_set[0].primaryRole,
        'reader')

  def testAdditionalRole(self):
    self.assertEqual(
        self.entry.additional_role_info[0].additional_role_set[0].\
            additional_role[0].value, 'commenter')


def suite():
  return conf.build_suite(
      [DataClassSanityTest, CategoryTest, DocsHelperTest, DocsEntryTest,
       AclTest, AclFeed, MetadataTest])


if __name__ == '__main__':
  unittest.main()



#!/usr/bin/python2.4
#
# Copyright 2011 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Sample app for Google Apps Calendar Resource features.

  CalendarResourceSample: Demonstrates the use of the Calendar Resource API
"""


__author__ = 'pti@google.com (Prashant Tiwari)'


import getpass
from gdata.calendar_resource.client import CalendarResourceClient


class CalendarResourceSample(object):
  def __init__(self, domain, email, password):
    """Constructor for the CalendarResourceSample object.

    Construct a CalendarResourceSample with the given args.

    Args:
      domain: The domain name ("domain.com")
      email: The email account of the user or the admin ("john@domain.com")
      password: The domain admin's password
    """
    self.client = CalendarResourceClient(domain=domain)
    self.client.ClientLogin(email=email, password=password,
                            source='googlecode-calendarresourcesample-v1')


  def create(self, resource_properties):
    """Creates a calendar resource with the given resource_properties
    
    Args:
      resource_properties: A dictionary of calendar resource properties
    """
    print 'Creating a new calendar resource with id %s...' % (
        resource_properties['resource_id'])
    print self.client.CreateResource(
        resource_id=resource_properties['resource_id'],
        resource_common_name=resource_properties['resource_name'],
        resource_description=resource_properties['resource_description'],
        resource_type=resource_properties['resource_type'])

  def get(self, resource_id=None):
    """Retrieves the calendar resource with the given resource_id
    
    Args:
      resource_id: The optional calendar resource identifier
    """
    if resource_id:
      print 'Retrieving the calendar resource with id %s...' % (resource_id)
      print self.client.GetResource(resource_id=resource_id)
    else:
      print 'Retrieving all calendar resources...'
      print self.client.GetResourceFeed()

  def update(self, resource_properties):
    """Updates the calendar resource with the given resource_properties
    
    Args:
      resource_properties: A dictionary of calendar resource properties
    """
    print 'Updating the calendar resource with id %s...' % (
        resource_properties['resource_id'])
    print self.client.UpdateResource(
        resource_id=resource_properties['resource_id'],
        resource_common_name=resource_properties['resource_name'],
        resource_description=resource_properties['resource_description'],
        resource_type=resource_properties['resource_type'])

  def delete(self, resource_id):
    """Deletes the calendar resource with the given resource_id
    
    Args:
      resource_id: The unique calendar resource identifier
    """
    print 'Deleting the calendar resource with id %s...' % (resource_id)
    self.client.DeleteResource(resource_id)
    print 'Calendar resource successfully deleted.'


def main():
  """Demonstrates the Calendar Resource API using CalendarResourceSample."""
  domain = None
  admin_email = None
  admin_password = None
  do_continue = 'y'
  print("Google Apps Calendar Resource API Sample\n\n")
  while not domain:
    domain = raw_input('Google Apps domain: ')
  while not admin_email:
    admin_email = '%s@%s' % (raw_input('Administrator username: '), domain)
  while not admin_password:
    admin_password = getpass.getpass('Administrator password: ')

  sample = CalendarResourceSample(domain=domain, email=admin_email,
                                  password=admin_password)

  while do_continue.lower() != 'n':
    do_continue = call_service(sample)


def call_service(sample):
  """Calls the service methods on the user input"""
  operation = None

  while operation not in ['c', 'C', 'g', 'G', 'u', 'U', 'd', 'D', 'q', 'Q']:
    operation = raw_input('Do [c=create|g=get|u=update|d=delete|q=quit]: ')

  operation = operation.lower()

  if operation == 'q':
    return 'n'

  resource_properties = get_input(operation)

  if operation == 'c':
    sample.create(resource_properties)
  elif operation == 'g':
    sample.get(resource_properties['resource_id'])
  elif operation == 'u':
    sample.update(resource_properties)
  elif operation == 'd':
    sample.delete(resource_properties['resource_id'])

  do_continue = None
  while do_continue not in ['', 'y', 'Y', 'n', 'N']:
    do_continue = raw_input('Want to continue (Y/n): ')

  if do_continue == '':
    do_continue = 'y'

  return do_continue.lower()


def get_input(operation):
  """Gets user input from console"""
  resource_id = None
  resource_name = None
  resource_description = None
  resource_type = None

  if operation == 'g':
    resource_id = raw_input('Resource id (leave blank to get all resources): ')
  else:
    while not resource_id:
      resource_id = raw_input('Resource id: ')

  if operation == 'c':
    resource_name = raw_input('Resource common name (recommended): ')
    resource_description = raw_input('Resource description (recommended): ')
    resource_type = raw_input('Resource type (recommended): ')
  elif operation == 'u':
    resource_name = raw_input(
        'New resource common name (leave blank if no change): ')
    resource_description = raw_input(
        'New resource description (leave blank if no change): ')
    resource_type = raw_input('New resource type (leave blank if no change): ')

  resource_properties = {'resource_id': resource_id,
                         'resource_name': resource_name,
                         'resource_description': resource_description,
                         'resource_type': resource_type}
  return resource_properties


if __name__ == '__main__':
  main()
